@@ -105,6 +105,8 @@ def prompt_rsa_fingerprints(ip, fingerprint):
     if accept_rsa_fingerprints == 'no':
         sys.exit(1)
 
+    return accept_rsa_fingerprints
+
 def create_keyless_ssh_ring(public_ips, user):
     """Create keyless SSH ring from primed servers"""
 
@@ -136,13 +138,14 @@ def prime_connections(public_ips, user):
         rsa_key = exe('ssh-keyscan -t rsa {0}'.format(ip))[0]
         with tempfile.NamedTemporaryFile() as tmp_file:
             tmp_file.write(rsa_key)
+            tmp_file.flush()
 
             # Generate fingerprint
             fingerprint = exe('ssh-keygen -l -f {0}'.format(tmp_file.name))[0].split()[1]
 
         # If performing individual authentication, prompt
         if accept_rsa_fingerprints != 'all':
-            prompt_rsa_fingerprints(ip, fingerprint)
+            accept_rsa_fingerprints = prompt_rsa_fingerprints(ip, fingerprint)
         
         # Append all public RSA keys into HOST_FILE
         with open(HOST_FILE, 'a') as f:
@@ -256,7 +259,7 @@ options_tree = {
     },
     'version': {
         'Section': 'Cassandra',
-        'Prompt': 'Version',
+        'Prompt': 'Version:',
         'Help': 'Community | Enterprise'
     },
     'username': {
@@ -305,7 +308,7 @@ def type_checker(option, read_option, type_check, passive=False):
             read_option = type_check(read_option)
         except:
             if passive:
-                return False
+                return None
             sys.stderr.write('"{0}" was expected to be of {1}\n'.format(option, type_check))
             sys.exit(1)
     return read_option
@@ -440,7 +443,7 @@ def main():
     clusterinfo = ec2.create_cluster(check_cascading_options('aws_access_key_id'), check_cascading_options('aws_secret_access_key'),
                                     totalnodes, image, tag, KEY_PAIR,
                                     instance_type, config.get('EC2', 'placement'), PEM_HOME,
-                                    user_data)
+                                    user_data, cli_options['CLI_noprompts'])
 
     # Save IPs
     global private_ips
@@ -450,12 +453,6 @@ def main():
     # Log clusterinfo
     running_log(reservation, demotime)
 
-    # Print a warning message if the pem file can't be found
-    if not os.path.isfile(PEM_FILE):
-        print "WARNING: The created pem file no longer exists at %s!" % PEM_FILE
-        print "         Please copy it out of the previous 'pem_home' directory."
-        print
-
     # Print SSH commands
     print 'Unprimed Connection Strings:'
     for publicIP in public_ips:
